PRO MODIS_CREFL_GEOTIFF, QKM_PROJ_TIFF, HKM_PROJ_HDF, OUT_TIFF, BANDS=BANDS

;+
; Create MODIS 250 meter enhanced RGB GeoTIFF output given reprojected
; input files created by modis_crefl_geotiff.csh
;
; Usage
; MODIS_CREFL_GEOTIFF, QKM_PROJ_TIFF, HKM_PROJ_HDF, OUT_TIFF
;
; Input
; QKM_PROJ_TIFF is the reprojected corrected reflectance (GeoTIFF) from QKM band 1
; HKM_PROJ_HDF  is the reprojected corrected reflectance (HDF) from HKM (must include band 1)
;
; Output
; OUT_TIFF is the output GeoTIFF file name
;-

;- Check arguments
if (n_elements(bands) eq 0) then bands = [1, 4, 3]

;- Read reprojected QKM band 1 and get GeoTIFF information
band01_250 = read_tiff(qkm_proj_tiff, geotiff=geotiff)

;- Open HKM HDF file
hdfid = hdf_sd_start(hkm_proj_hdf)

;- Read reprojected HKM band 1
hdf_sd_varread, hdfid, 'CorrRefl_01', band01_500

;- Compute sharpening ratio
ratio = temporary(band01_500) / float(temporary(band01_250))

;- Read reprojected HKM red, green, and blue bands from HDF
hdf_sd_varread, hdfid, string(bands[0], format='("CorrRefl_", i2.2)'), red
hdf_sd_varread, hdfid, string(bands[1], format='("CorrRefl_", i2.2)'), grn
hdf_sd_varread, hdfid, string(bands[2], format='("CorrRefl_", i2.2)'), blu

;- Close HKM HDF file
hdf_sd_end, hdfid

;- Convert to reflectance
red = temporary(red) * 0.0001
grn = temporary(grn) * 0.0001
blu = temporary(blu) * 0.0001

;- Create sharpened red, green, blue bands
red = temporary(red) / ratio
grn = temporary(grn) / ratio
blu = temporary(blu) / ratio

;- Create RGB image
true = modis_false_color(temporary(red), temporary(grn), temporary(blu))

;- Enhance lightness and saturation for true color images
if (bands[0] eq 1) and $
   (bands[1] eq 4) and $
   (bands[2] eq 3) then $
  true = adjust(temporary(true))

;- Write GeoTIFF true color image
write_tiff, out_tiff, true, 1, planarconfig=2, geotiff=geotiff, compress=1
print, out_tiff, format='("(Created GeoTIFF image ", a, ")")'

END
